@@ -21,7 +21,7 @@
  *  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  *  DEALINGS IN THE SOFTWARE. 
  *
- *  $Id: catalog.cpp 1008 2006-05-28 19:24:57Z vaclavslavik $
+ *  $Id: catalog.cpp 1047 2006-10-08 18:37:53Z vaclavslavik $
  *
  *  Translations catalog
  *
@@ -283,7 +283,7 @@ void Catalog::HeaderData::UpdateDict()
         SetHeader(_T("X-Poedit-KeywordsList"), kw);
     }
 
-    int i;
+    unsigned i;
     bool noBookmarkSet = true;
     wxString bk;
     for (i = 0; i < BOOKMARK_LAST ; i++)
@@ -368,7 +368,6 @@ void Catalog::HeaderData::ParseDict()
     {
         Charset = _T("iso-8859-1");
     }
-    if (!ReadParam(ctype, _T("text/plain; charset="), Charset))
 
 
     // Parse extended information:
@@ -481,7 +480,6 @@ void Catalog::HeaderData::DeleteHeader(const wxString& key)
     {
         Entries enew;
 
-        size_t size = m_entries.size();
         for (Entries::const_iterator i = m_entries.begin();
                 i != m_entries.end(); i++)
         {
@@ -735,6 +733,8 @@ bool CatalogParser::Parse()
         else
             line = ReadTextLine(m_textFile, m_conv);
     }
+
+    return true;
 }
 
 
@@ -957,7 +957,8 @@ bool Catalog::Load(const wxString& po_file)
 
     m_data = new wxHashTable(wxKEY_STRING);
 
-    if (!f.Open(po_file)) return false;
+    if (!f.Open(po_file, wxConvISO8859_1))
+        return false;
 
     CharsetInfoFinder charsetFinder(&f, &wxConvISO8859_1);
     charsetFinder.Parse();
@@ -965,7 +966,8 @@ bool Catalog::Load(const wxString& po_file)
 
     f.Close();
     wxCSConv encConv(m_header.Charset);
-    if (!f.Open(po_file, encConv)) return false;
+    if (!f.Open(po_file, encConv))
+        return false;
 
 #if wxUSE_UNICODE
     if (!VerifyFileCharset(f, po_file, m_header.Charset))
@@ -985,10 +987,14 @@ bool Catalog::Load(const wxString& po_file)
     }
 
     // now that the catalog is loaded, update its items with the bookmarks
-    for(int i = BOOKMARK_0; i < BOOKMARK_LAST; i++)
+    for (unsigned i = BOOKMARK_0; i < BOOKMARK_LAST; i++)
     {
-        if (m_header.Bookmarks[i] != -1 && m_header.Bookmarks[i] < m_dataArray.GetCount())
-            m_dataArray[m_header.Bookmarks[i]].SetBookmark(static_cast<Bookmark>(i));
+        if (m_header.Bookmarks[i] != -1 &&
+            m_header.Bookmarks[i] < (int)m_dataArray.GetCount())
+        {
+            m_dataArray[m_header.Bookmarks[i]].SetBookmark(
+                    static_cast<Bookmark>(i));
+        }
     }
 
 
