@@ -21,7 +21,7 @@
  *  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  *  DEALINGS IN THE SOFTWARE. 
  *
- *  $Id: edframe.cpp 1035 2006-09-04 08:52:18Z vaclavslavik $
+ *  $Id: edframe.cpp 1051 2006-10-29 18:23:21Z vaclavslavik $
  *
  *  Editor frame
  *
@@ -664,6 +664,9 @@ static GtkTextView *GetTextView(wxTextCtrl *ctrl)
         }
         child = child->next;
     }
+
+    wxFAIL_MSG( _T("couldn't find GtkTextView for text control") );
+    return NULL;
 }
 
 static void DoInitSpellchecker(wxTextCtrl *text,
@@ -1755,7 +1758,6 @@ void poEditFrame::RefreshControls()
     m_list->Refresh();
 
     wxString trans;
-    size_t pos = 0;
 
     m_list->Thaw();
 
@@ -2137,7 +2139,7 @@ void poEditFrame::OnHelp(wxCommandEvent&)
 void poEditFrame::OnHelpGettext(wxCommandEvent&)
 {
 #ifdef __WXMSW__
-    m_help.LoadFile(wxGetApp().GetAppPath() + _T("/share/poedit/gettext.chm"));
+    m_help.LoadFile(m_helpBookGettext);
     m_help.DisplayContents();
 #endif
 }
@@ -2489,8 +2491,8 @@ void poEditFrame::RecreatePluralTextCtrls()
     PluralFormsCalculator *calc = PluralFormsCalculator::make(
                 m_catalog->Header().GetHeader(_T("Plural-Forms")).ToAscii());
 
-    unsigned cnt = m_catalog->GetPluralFormsCount();
-    for (unsigned i = 0; i < cnt; i++)
+    int cnt = m_catalog->GetPluralFormsCount();
+    for (int i = 0; i < cnt; i++)
     {
         // find example number that would use this plural form:
         unsigned example = 0;
@@ -2511,9 +2513,9 @@ void poEditFrame::RecreatePluralTextCtrls()
 
         wxString desc;
         if (example == 1000)
-            desc.Printf(_("Form %u"), i);
+            desc.Printf(_("Form %i"), i);
         else
-            desc.Printf(_("Form %u (e.g. \"%u\")"), i, example);
+            desc.Printf(_("Form %i (e.g. \"%u\")"), i, example);
 
         // create text control and notebook page for it:
         wxTextCtrl *txt = new wxTextCtrl(m_pluralNotebook, -1,
@@ -2572,16 +2574,26 @@ void poEditFrame::AddBookmarksMenu()
 {
     wxMenu *menu = new wxMenu();
 
+#ifdef __WXMAC__
+    // on Mac, Alt+something is used during normal typing, so we shouldn't
+    // use it as shortcuts:
+    #define LABEL_BOOKMARK_SET   _("Set bookmark %i\tCtrl-%i")
+    #define LABEL_BOOKMARK_GO    _("Go to bookmark %i\tCtrl-Alt-%i")
+#else
+    #define LABEL_BOOKMARK_SET   _("Set bookmark %i\tAlt-%i")
+    #define LABEL_BOOKMARK_GO    _("Go to bookmark %i\tCtrl-%i")
+#endif
+
     for (int i = 0; i < 10; i++)
     {
         menu->Append(ID_BOOKMARK_SET + i,
-                     wxString::Format(_("Set bookmark %i\tAlt-%i"), i, i));
+                     wxString::Format(LABEL_BOOKMARK_SET, i, i));
     }
     menu->AppendSeparator();
     for (int i = 0; i < 10; i++)
     {
         menu->Append(ID_BOOKMARK_GO + i,
-                     wxString::Format(_("Go to bookmark %i\tCtrl-%i"), i, i));
+                     wxString::Format(LABEL_BOOKMARK_GO, i, i));
     }
 
     wxMenuBar *bar = GetMenuBar();
