@@ -21,7 +21,7 @@
  *  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  *  DEALINGS IN THE SOFTWARE.
  *
- *  $Id: findframe.cpp 1011 2006-07-09 14:32:30Z vaclavslavik $
+ *  $Id: findframe.cpp 1045 2006-10-08 11:40:52Z vaclavslavik $
  *
  *  Search frame
  *
@@ -191,7 +191,7 @@ bool TextInString(const wxString& str, const wxString& text, bool wholeWords)
     {
         if (wholeWords)
         {
-            int textLen = text.Length();
+            unsigned textLen = text.Length();
 
             bool result = true;
             if (index >0)
@@ -328,6 +328,8 @@ bool FindFrame::DoFind(int dir)
             case Found_InAutoComments:
               txt = m_textCtrlAutoComments;
               break;
+            case Found_Not: // silence compiler warning, can't get here
+              break;
         }
 
         textc = txt->GetValue();
