@@ -10,8 +10,12 @@ _("Edit the file in text editor");
 _("Find...");
 _("String to find:");
 _("Case sensitive");
+_("Start from the first item");
+_("Whole words only");
 _("Find in original strings");
 _("Find in translations");
+_("Find in comments");
+_("Find in automatic comments");
 _("Cancel");
 _("< Previous");
 _("Next >");
@@ -31,6 +35,7 @@ _("&Close");
 _("&File");
 _("Catalogs &manager");
 _("&New catalog...");
+_("New catalog from POT file...");
 _("&Open");
 _("&Save");
 _("Save &as...");
@@ -47,12 +52,14 @@ _("C&atalog");
 _("&Update from sources");
 _("Update from &POT file...");
 _("&Automatically translate using TM");
+_("&Purge deleted translations");
 _("&Settings...");
 _("&View");
 _("&Fullscreen view");
 _("Display &quotes");
 _("Display &line numbers");
 _("Show &comment window");
+_("Show automatic c&omments window");
 _("&Shaded translations list");
 _("&Contents...");
 _("GNU gettext documentation");
